--- a/phoneapp/phoneuicontrol/src/cphonestate.cpp Fri Jul 23 12:55:58 2010 +0300
+++ b/phoneapp/phoneuicontrol/src/cphonestate.cpp Fri Aug 06 13:16:44 2010 +0300
@@ -501,8 +501,7 @@
__PHONELOG( EBasic, EPhoneControl, "SIM card was removed" );
TPhoneCmdParamGlobalNote globalNoteParam;
- globalNoteParam.SetType( EAknGlobalInformationNote );
- globalNoteParam.SetTone( EAvkonSIDNoSound );
+ globalNoteParam.SetType( EPhoneMessageBoxInformation );
globalNoteParam.SetTextResourceId(
CPhoneMainResourceResolver::Instance()->
@@ -2125,9 +2124,9 @@
noteText.Append( timeString );
TPhoneCmdParamGlobalNote globalNoteParam;
- globalNoteParam.SetType( EAknGlobalInformationNote );
+ globalNoteParam.SetType( EPhoneMessageBoxInformation );
globalNoteParam.SetText( noteText );
- globalNoteParam.SetTone( CAknNoteDialog::ENoTone );
+
iViewCommandHandle->ExecuteCommandL(
EPhoneViewShowGlobalNote, &globalNoteParam );
}
@@ -2152,12 +2151,13 @@
&globalNotifierParam );
TPhoneCmdParamGlobalNote globalNoteParam;
-
- globalNoteParam.SetType( EAknGlobalInformationNote );
+ PhoneNotificationType type = aNotificationDialog ?
+ EPhoneNotificationDialog : EPhoneMessageBoxInformation;
+ globalNoteParam.SetType( type );
globalNoteParam.SetTextResourceId(
CPhoneMainResourceResolver::Instance()->
ResolveResourceID( aResourceId ) );
- globalNoteParam.SetTone( EAvkonSIDInformationTone );
+
globalNoteParam.SetNotificationDialog( aNotificationDialog );
iViewCommandHandle->ExecuteCommandL(
@@ -2185,11 +2185,13 @@
&globalNotifierParam );
TPhoneCmdParamGlobalNote globalNoteParam;
- globalNoteParam.SetType( EAknGlobalWarningNote );
+ PhoneNotificationType type = aNotificationDialog ?
+ EPhoneNotificationDialog : EPhoneMessageBoxWarning;
+ globalNoteParam.SetType( type );
globalNoteParam.SetTextResourceId(
CPhoneMainResourceResolver::Instance()->
ResolveResourceID( aResourceId ) );
- globalNoteParam.SetTone( EAvkonSIDWarningTone );
+
globalNoteParam.SetNotificationDialog( aNotificationDialog );
iViewCommandHandle->ExecuteCommandL(
@@ -2216,11 +2218,13 @@
&globalNotifierParam );
TPhoneCmdParamGlobalNote globalNoteParam;
- globalNoteParam.SetType( EAknGlobalErrorNote );
+ PhoneNotificationType type = aNotificationDialog ?
+ EPhoneNotificationDialog : EPhoneMessageBoxInformation;
+ globalNoteParam.SetType( type );
+
globalNoteParam.SetTextResourceId(
CPhoneMainResourceResolver::Instance()->
ResolveResourceID( aResourceId ) );
- globalNoteParam.SetTone( CAknNoteDialog::EErrorTone );
globalNoteParam.SetNotificationDialog( aNotificationDialog );
iViewCommandHandle->ExecuteCommandL(
@@ -2818,13 +2822,13 @@
resource = iCustomization->CustomizeBusyNoteText();
}
// Show number busy note
TPhoneCmdParamGlobalNote globalNoteParam;
- globalNoteParam.SetType( EAknGlobalInformationNote );
+ globalNoteParam.SetType( EPhoneNotificationDialog );
globalNoteParam.SetTextResourceId(
CPhoneMainResourceResolver::Instance()->
ResolveResourceID( resource ) );
- globalNoteParam.SetTone( EAvkonSIDInformationTone );
+
globalNoteParam.SetNotificationDialog( ETrue );
iViewCommandHandle->ExecuteCommandL( EPhoneViewShowGlobalNote,
&globalNoteParam );
@@ -3160,8 +3164,8 @@
TPhoneCmdParamGlobalNote globalNoteParam;
globalNoteParam.SetText( callText );
- globalNoteParam.SetType( EAknGlobalInformationNote );
- globalNoteParam.SetTone( EAvkonSIDInformationTone );
+ globalNoteParam.SetType( EPhoneNotificationDialog );
+
globalNoteParam.SetTextResourceId(
CPhoneMainResourceResolver::Instance()->
ResolveResourceID( EPhoneCallWaitingWithLabel ) );
@@ -3302,9 +3306,8 @@
TPhoneCmdParamGlobalNote globalNoteParam;
globalNoteParam.SetText( *buf );
- globalNoteParam.SetType( EAknGlobalInformationNote );
- globalNoteParam.SetTone( EAvkonSIDInformationTone );
-
+ globalNoteParam.SetType( EPhoneMessageBoxInformation );
+
iViewCommandHandle->ExecuteCommandL(
EPhoneViewShowGlobalNote, &globalNoteParam );
@@ -2818,13 +2822,13 @@
resource = iCustomization->CustomizeBusyNoteText();
}
- // Show number busy note
+ // Show number busy notification
TPhoneCmdParamGlobalNote globalNoteParam;